@@ -1,38 +1,22 @@
-////////////////////////////////////////////////////////////////////////////////
-//    Copyright (c) 1996 - 2008, HP Development Company, L.P.
-//    All rights reserved.
-//    
-//    This software is licensed solely for use with HP products.  Redistribution
-//    and use with HP products in source and binary forms, with or without
-//    modification, are permitted provided that the following conditions are met:
-//    
-//    -   Redistributions of source code must retain the above copyright notice,
-//        this list of conditions and the following disclaimer.
-//    -   Redistributions in binary form must reproduce the above copyright
-//        notice, this list of conditions and the following disclaimer in the
-//        documentation and/or other materials provided with the distribution.
-//    -   Neither the name of HP nor the names of its contributors
-//        may be used to endorse or promote products derived from this software
-//        without specific prior written permission.
-//    -   Redistributors making defect corrections to source code grant to
-//        HP the right to use and redistribute such defect
-//        corrections.
-//    
-//    This software contains technology licensed from third parties; use with
-//    non-HP products is at your own risk and may require a royalty.
-//    
-//    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-//    'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
-//    TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-//    PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL HP OR ITS
-//    CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-//    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-//    PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-//    OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-//    WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-//    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-//    ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-////////////////////////////////////////////////////////////////////////////////
+/*****************************************************************************\
+  
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+   MA 02111-1307, USA.
+
+\
+\*****************************************************************************/
 
 
 
