@@ -1,24 +1,28 @@
+/*****************************************************************************\
+  
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+   MA 02111-1307, USA.
+
+\
+\*****************************************************************************/
 #ifndef PCLM_COMMON_DEFINES
 #define PCLM_COMMON_DEFINES
 
 #define PCLM_Ver 0.93
 #define STANDALONE
 
-/*###########################################################
-*
-*  Copyright (c) HP Company, 2006.
-*  All rights reserved.  Copying or other reproduction of this
-*  program except for archival purposes is prohibited without
-*  the prior written consent of HP Company.
-*
-*  File: Print2/GE/src/mpression.cpp
-*
-*  HP COMPANY
-*  11311 Chinden Boulevard
-*  Boise, Idaho  83714
-*
-*##########################################################*/
-
 typedef unsigned char   ubyte;          /* unsigned byte: 0..255           */
 typedef signed   char   sbyte;          /* signed byte: -128..127          */
 typedef unsigned char   uint8;          /* unsigned byte: 0..255           */
